@@ -12,6 +12,8 @@ Exports only time_encode and time_decode functions.
 
 import re
 
+__all__ = ['time_encode', 'time_decode']
+
 second = 1
 minute = second*60
 hour = minute*60
@@ -46,7 +48,7 @@ def time_decode(s):
     """Decodes a number in the format 1h4d3m (1 hour, 3 days, 3 minutes)
     into a number of seconds"""
     time = 0
-    for match in all_matches(s, time_re):
+    for match in time_re.finditer(s):
         char = match.group(0)[-1].lower()
         if not time_values.has_key(char):
             # @@: should signal error
@@ -54,17 +56,4 @@ def time_decode(s):
         time += int(match.group(0)[:-1]) * time_values[char]
     return time
 
-def all_matches(source, regex):
-    """
-    Return a list of matches for regex in source
-    """
-    pos = 0
-    end = len(source)
-    rv = []
-    match = regex.search(source, pos)
-    while match:
-        rv.append(match)
-        match = regex.search(source, match.end() )
-    return rv
-
 __all__ = ['time_encode', 'time_decode']
